Package: lisrelToR
Type: Package
Title: Import Output from LISREL into R
Version: 0.3
Depends: R (>= 2.15.0)
Author: Sacha Epskamp
Maintainer: Sacha Epskamp <mail@sachaepskamp.com>
Description: This is an unofficial package aimed at automating the import of LISREL output in R. 
				This package or its maintainer is not in any way affiliated with the creators of LISREL and SSI, Inc.
License: GPL-2
NeedsCompilation: no
Packaged: 2024-02-07 01:59:22 UTC; sachaepskamp
Repository: CRAN
Date/Publication: 2024-02-07 12:50:13 UTC
Built: R 4.6.0; ; 2026-04-26 13:10:21 UTC; unix
